@@ -44,10 +44,11 @@ def saveFile(file_name,content, paper,dwn_source):
     paper.downloadedFrom = dwn_source
             
     
-def downloadPapers(papers, dwnl_dir, num_limit):
+def downloadPapers(papers, dwnl_dir, num_limit, SciHub_URL=None):
     def URLjoin(*args):
         return "/".join(map(lambda x: str(x).rstrip('/'), args))
-
+      
+    NetInfo.SciHub_URL = SciHub_URL
     if NetInfo.SciHub_URL==None:
         setSciHubUrl()
     
